Color management filters for Thumbor
====================================

A collection of thumbor filters providing better support for color managed images.

Usage
-----


http://localhost:8888/unsafe/filters:icc_profile_apply(sRGB)/http://localhost:8081/path/to/file.tif


License
-------

The software is subject to the MIT license.
